@@ -41,7 +41,7 @@ class Secret(NamespacedResource):
         self.string_data = string_data
         self.type = type
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
         if not self.yaml_file:
             if self.accesskeyid:
